{% extends 'pybb/base.html' %}
{% load pybb_tags i18n %}

{% block title %}{% trans "Editing the post" %}{% endblock title %}

{% block more_head %}
    {{ block.super }}
    {% include "pybb/markitup.html" %}
{% endblock more_head %}

{% block content %}
    <h1>{% trans "Editing the post" %}</h1>
    {% include "pybb/post_form.html" %}
{% endblock content %}

{% block breadcrumb %}
    {% with extra_crumb="Edit post" %}
        {% include "pybb/breadcrumb.html" %}
    {% endwith %}
    
{% endblock %}
