{% extends 'pybb/base.html' %}
{% load i18n %}

{% block title %}{{ PYBB_DEFAULT_TITLE }}{% endblock title %}

{% block breadcrumb %}
    {% with extra_crumb="Forum" %}{% include "pybb/breadcrumb.html" %}{% endwith %}
{% endblock %}

{% block content %}
    {% if categories %}
        {% for category in categories %}
            {% include 'pybb/category.html' %}
        {% endfor %}
    {% else %}
        <h2>{% trans "Forum categories are not created" %}</h2>
        <a href="{% url admin:pybb_category_add %}">{% trans "Add a category now" %}</a>
    {% endif %}
    {% if user.is_authenticated %}
        <div id='mark-all-as-read'>
            <a href='{% url pybb:mark_all_as_read %}'>
                {% trans "Mark all forums as read" %}
            </a>
        </div>
    {% endif %}
{% endblock content %}
