{% extends 'pybb/base.html' %}
{% load pybb_tags i18n %}

{% block content %}
    <h1><a href="{{ profile.pybb_profile.get_absolute_url }}">{{ profile.username }}</a></h1>
    <div class="userinfo">
        <div class="avatar">
            <img src="{{ profile.pybb_profile.avatar_url }}" alt="" />
        </div>
        {% for topic in list %}
        <li class="user">

        <span class="post_count">{{ topic.posts.count }}</span>
        <span class="updated">{{ topic.created|date:"d M Y h:i" }}</span>
        <a href={% url pybb_post topic.id %}>{{ topic.body_text }}</a>
        </li>
        {% endfor %}

        {% with _('Topics') as label %}
        {% include "pybb/pagination.html" %}
        {% endwith %}

    </div>
{% endblock %}
