{% load pytils_numeral %}
<!DOCTYPE html>
<html>
<head>
    <meta http-equiv="content-type" content="application/html; charset=utf-8">
    <!-- Le HTML5 shim, for IE6-8 support of HTML elements -->
    <!--[if lt IE 9]>
            <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->
    <link rel="stylesheet" href="{{ STATIC_URL }}pybb_bootstrap.css" type='text/css'>

    <link rel="stylesheet" href="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/themes/smoothness/jquery-ui.css" type="text/css" />
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/1.5.1/jquery.min.js"></script>
    <script src="https://ajax.googleapis.com/ajax/libs/jqueryui/1.8/jquery-ui.min.js"></script>
    <script src="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/i18n/jquery-ui-i18n.min.js"></script>
    <script src="http://yandex.st/json2/2011-01-18/json2.min.js"></script>
    <script src="{{ STATIC_URL }}csrf.js"></script>
    <style type="text/css">
        body {
            padding-top: -60px;
        }
    </style>
    <title>{% block title %}{% endblock %}</title>

    {% block more_head %}{% endblock %}
</head>
<body>

<div class="topbar">
    <div class="fill">
        <div class="container">
            <a class="brand" href="/">PYBB Modified. Django forum solution.</a>
            <ul class="nav">
                {% if request.user.is_authenticated %}
                    <li>
                        <a href="{% url pybb:edit_profile %}">Profile [logged as {{ request.user.username }}]</a>
                    </li>
                    <li>
                        <a href="{% url auth_logout %}">Logout</a>
                    </li>
                    {% if request.user.is_superuser %}
                        <li>
                            <a href="{% url admin:index %}">Admin interface</a>
                        </li>
                    {% endif %}

                {% else %}
                    <li>
                        <a href="{% url auth_login %}">Login</a>
                    </li>
                    <li>
                        <a href="{% url registration_register %}">Register</a>
                    </li>
                {% endif %}
                <li><a href="http://github.com/hovel/pybbm">Code</a></li>
                <li><a href="http://pypi.python.org/pypi/pybbm">Download</a></li>
                <li><a href="http://readthedocs.org/docs/pybbm/en/latest/">Documentation</a></li>
            </ul>
        </div>
    </div>
</div>

<div class="container">

    <!-- Main hero unit for a primary marketing message or call to action -->
    <div class="main-block">
        {% if messages %}
            <ul class="messages">
                {% for message in messages %}
                    <li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message }}</li>
                {% endfor %}
            </ul>
        {% endif %}
        {% if request.path != '/' %}
            <div id="breadcrumb">
                {% block breadcrumb %}
                    <a href="/">Main</a>
                {% endblock breadcrumb %}
            </div>
        {% endif %}
        {% if request.path == '/' %}
            <div class='forum-headline'>
                This is a default installation of PyBBModified with default theme from example.
            </div>
        {% endif %}
        <div id="content">
            {% block content %}
            {% endblock content %}
        </div>
    </div>
    {% if request.path == '/' %}
    <div class="row">
        <div class="span5">
            <h2>Fully Documented</h2>
            <p>Everything explained</p>
            <p><a class="btn" href="http://readthedocs.org/docs/pybbm/en/latest/">Read docs now &raquo;</a></p>
        </div>
        <div class="span5">
            <h2>Heavy tested</h2>
            <p> 95% code coverage!</p>
            <p><a class="btn" href="https://bitbucket.org/zeus/pybb/src/tip/pybb/tests.py">View tests &raquo;</a></p>
        </div>
        <div class="span5">
            <h2>Want a fast start?</h2>
            <p>Start from ready to use example project</p>
            <p><a class="btn" href="http://readthedocs.org/docs/pybbm/en/latest/example.html">Read more &raquo;</a></p>
        </div>
    </div>

    <div class="row spaced">
        <div class="span5">
            <h2>Django application</h2>
            <p>Easy to embed to any django project</p>
            <p><a class="btn success" href="http://readthedocs.org/docs/pybbm/en/latest/install.html">Learn how to install &raquo;</a></p>
        </div>
        <div class="span5">
            <h2>Help welcomed</h2>
            <p>Extended PyBBM? Push your changes.</p>
            <p><a class="btn" href="https://bitbucket.org/zeus/pybb">Fork repo &raquo;</a></p>
        </div>
    </div>
    {% endif %}

    <footer>
        powerd by:
        <a href="http://www.djangoproject.com">django</a>,
        <a href="http://www.pybbm.org">pybbm</a>
    </footer>

</div> <!-- /container -->
</body>
<script type="text/javascript">

    var _gaq = _gaq || [];
    _gaq.push(['_setAccount', 'UA-27006117-1']);
    _gaq.push(['_setDomainName', 'pybbm.org']);
    _gaq.push(['_trackPageview']);

    (function() {
        var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
        ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
        var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
    })();

</script>
</html>
