{% if PYBB_ATTACHMENT_ENABLE %}
    {% load i18n %}
    <div class='attachments-form'>
        <a class='attachment-link' onclick='$("div.attachments-form table").toggle();return false;' href='#'>{% trans "Add attachments" %}</a>
        {{ aformset.management_form }}
            <table style='display:none;'>
            {% for form in aformset %}
                <tr>
                    <td>{{ form.id }} {{ form.file }}</td>
                    <td>{{ form.DELETE }} {% trans "delete" %}</td>
                </tr>
            {% endfor %}
            </table>
    </div>
{% endif %}