{% extends 'pybb/base.html' %}
{% load i18n pybb_tags %}

{% block more_head %}
    {{ block.super }}
    {% include "pybb/markitup.html" %}
{% endblock more_head %}

{% block breadcrumb %}
    {% if forum %}
        {% with object=forum extra_crumb="New topic" %}
            {% include 'pybb/breadcrumb.html' %}
        {% endwith %}
    {% else %}
        {% with object=topic extra_crumb="New reply" %}
            {% include 'pybb/breadcrumb.html' %}
        {% endwith %}
    {% endif %}
{% endblock %}

{% block content %}

<h1>{% if forum %}{% trans "New topic" %}{% else %}{% trans "New reply" %}{% endif %}</h1>

{% include "pybb/post_form.html" %}
{% endblock content %}
