{% load thumbnail %}

<div class="avatar">
    <a href="{{ post.user.get_profile.get_absolute_url }}">
        {% if post.user.get_profile.avatar %}
        <img src="{% thumbnail post.user.get_profile.avatar 80x80  %}" alt="{{ post.user }} sin avatar" />
        {% else %}
        <img src="{{PYBB_DEFAULT_AVATAR_URL}}" alt="Avatar" />
        {% endif %}
    </a>
</div>
