{% extends PYBB_TEMPLATE|default:"base.html" %}
{% load i18n pybb_tags %}

{%block title %}{{ PYBB_DEFAULT_TITLE }}{% endblock title %}

{% block more_head %}
    {% block pybb_styles_extra %}{% endblock %}
    <!-- Feeds -->
    <link rel="alternate" type="application/atom+xml" href="{% url pybb:feed_posts %}" title="{% trans "Latest posts on forum" %}" >
    <link rel="alternate" type="application/atom+xml" href="{% url pybb:feed_topics %}" title="{% trans "Latest topics on forum" %}" >
    {% block pybb_scripts_extra %}{% endblock %}
    {% block pybb_head_extra %}{% endblock %}
    <link rel="stylesheet" href="{{ STATIC_URL }}pybb.css" type="text/css" />
{% endblock head %}

{% block breadcrumb %}
    {% include "pybb/breadcrumb.html" %}
{% endblock %}

{% block content %}{% endblock content %}

