.post-preview{
    .well
}

.forum-headline {
    .alert-message;
    .alert-message.block-message;
    margin-top: 10px;
}

.main-block {
  background-color: #f5f5f5;
  margin-bottom: 30px;
  padding: 60px;
  .border-radius(6px)
}

.main-block h1{
    font-size: 24px;
}


.attachments-form {
    padding-bottom: 15px;
}

.attachment-link {
    border-bottom: 1px dotted;
}

blockquote{
    margin-top: 5px;
}

/* --- Unread --- */

.unread a{
    font-weight: bold;
}

.state-indicator {
    display: block;
    float: left;
    background-color: #CCC;
    height: 10px;
    width: 10px;
    border-radius: 5px;
    margin: 3px 5px;
}

.unread .state-indicator {
    background-color: #369;
}

/* --- Signature --- */
.signature {
    color: #CCC;
    margin-top: 15px;
    border-top: 1px dotted #CCC;
    display: block;
}

/* --- Moderation --- */
.on-moderation {
    background: #ffcccc;
}

/* --- Mini pagination --- */
.mini-pagination {
    padding: 3px 0 3px 10px;
    font-size: 80%;
}