/* --- Topic/Forum table --- */
.forum-description {
    margin: 5px;
    font-size: 80%;
}

.forum-row, .topic-row {
    width: 100%;
}

.forum-name, .topic-name {
    width: 40%;
}

.forum-topic-count, .forum-post-count, .topic-post-count, .topic-view-count {
    width: 16%;
    text-align: center;
}

.forum-last-post, .topic-last-post {
    width: 20%;
}

/* --- Posts ---*/

.posts {
    clear: both;
    width: 100%;
}

.post {
    width: 99%;
    margin: 3px 0 5px 0;
    clear: both;
}


.post .info {
    width: 200px;
    border: 1px solid #CCC;
    padding: 10px;
}

.post .info .extra-info {
    font-size: 80%;
    color: #CCC;
}

.post .content {
    vertical-align: top;
    padding: 10px;
    border: 1px solid #CCC;
}

.post-header {
   padding: 3px 0 3px 20px;
   font-size: 80%;
   background-color: #EEE;
   border: 1px solid #CCC;
}

.post-related {
    margin-top: 20px;
}

.post .info .author {
    font-size: 110%;
    padding: 5px;
}

.post .info .post-controls {
    font-size: 80%;
}