/* --- Controls --- */

input[type=submit] {
    .btn;
    .btn.success;
    &:hover{
            color: #FFF;
        }
}

.new-topic {
    .btn;
    .btn.primary;
    &:hover{
        color: #FFF;
    }
}

ul.errorlist {
    margin: 20px 0 0 0;
    display: block;
    clear: both;
}

.errorlist li{
    .label;
    .label.important;
    color: white;
}

.post-form, .profile-edit {
    .form-stacked;
}