{% load i18n pybb_tags %}
<ul class='breadcrumb'>
    {% if request.path != '/' %}
        <li><a href="/">{% trans "Home" %}</a> <span class="divider">/</span></li>
    {% endif %}
    {% if object %}
            {% if object.get_parents %}
            {% for obj in object.get_parents %}
                <li>{% pybb_link obj %} <span class="divider">/</span></li>
            {% endfor %}
        {% endif %}
        {% if extra_crumb %}
            <li>{% pybb_link object %} <span class="divider">/</span></li>
        {% else %}
            <li>{{ object }}</li>
        {% endif %}
    {% endif %}
    {% if extra_crumb %}
        <li>{% trans extra_crumb %}</li>
    {% endif %}
</ul>